@@ -25,24 +25,27 @@
 #    SOFTWARE.                                                                         #
 #                                                                                      #
 # ==================================================================================== #
-def validate(data: dict) -> bool:
-    if len(data) == 0:
-        return False
-    if len(data) == 1:
-        endpoint = list(data.keys())[0]
-        error = data[endpoint].get('error')
-        result = data[endpoint].get('result')
-        if error is not None:
-            return False
-        if result is None:
-            return False
-        if isinstance(result, dict | list):
-            if len(result) == 0:
-                return False
-        if isinstance(result, list):
-            if result[0] == {}:
-                return False
-    if len(data) > 1:
-        if 'news' in data and data['news'] == []:
-            return False
-    return True
+from .paths import base_url, paths
+from urllib.parse import urlencode
+
+
+# ------------------------------------------------------------------------------------ #
+def get_path(endpoint: str, params: dict) -> str:
+    path = paths[endpoint]
+    if '{symbol}' in path:
+        sym = params.pop('symbol', '')
+        path = path.format(symbol=sym)
+    return path
+
+
+# ------------------------------------------------------------------------------------ #
+def build_error(path: str, params: dict, ex=None) -> dict:
+    params = '?' + urlencode(params) if params else ''
+    default_message = 'Internal server error'
+    default_status = 500
+    return dict(
+        name='HTTPError',
+        status=getattr(ex, 'status', default_status),
+        message=getattr(ex, 'message', default_message),
+        url=base_url + path + params
+    )
